@@ -225,7 +225,7 @@ class CreateAPITestCaseMixin(object):
 
         :param data: A dictionary of the data to use for the create request.
         :param kwargs: Extra arguments that are passed to the client's ``post()`` call.
-        :returns: The view's response.
+        :returns: A tuple ``response, created`` of the view's response the created instance.
         """
 
         if data is None:
@@ -241,9 +241,9 @@ class CreateAPITestCaseMixin(object):
 
         # another sanity check:
         # getting the instance from database simply to see that it's found and does not raise any exception
-        self.object.__class__.objects.get(id=response.data.get('id'))
+        created = self.object.__class__.objects.get(id=response.data.get('id'))
 
-        return response
+        return response, created
 
     def _get_create_name(self):
         if hasattr(self, 'create_name'):
@@ -329,7 +329,7 @@ class UpdateAPITestCaseMixin(object):
         :param data: Data dictionary for the update request.
         :param results: Dictionary mapping instance properties to expected values.
         :param kwargs: Extra arguments that are passed to the client's ``put()`` or ``patch()`` call.
-        :returns: The view's response.
+        :returns: A tuple ``response, updated`` of the view's response the updated instance.
         """
 
         object_id = getattr(self.object, self.lookup_field)
@@ -353,12 +353,12 @@ class UpdateAPITestCaseMixin(object):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
         # getting a fresh copy of the object from DB
-        obj = self.object.__class__.objects.get(**{self.lookup_field: object_id})
+        updated = self.object.__class__.objects.get(**{self.lookup_field: object_id})
         # Sanity check:
         # check that the copy in the database was updated as expected.
-        self._update_check_db(obj, data, results)
+        self._update_check_db(updated, data, results)
 
-        return response
+        return response, updated
 
     def _get_update_name(self):
         if hasattr(self, 'update_name'):
